package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````OB4```````!``````````("Q````
M`````````$``.``-`$``'0`<``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````)`<````````D!P`````````
M$`````````$````%`````"``````````(``````````@````````O3X`````
M``"]/@`````````0`````````0````0`````8`````````!@`````````&``
M```````P2````````#!(`````````!`````````!````!@```,"K````````
MP+L```````#`NP```````&@$````````V`0`````````$`````````(````&
M````T*L```````#0NP```````-"[````````(`(````````@`@````````@`
M````````!`````0````X`P```````#@#````````.`,```````!`````````
M`$``````````"``````````$````!````'@#````````>`,```````!X`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````0`````````!```````````@`````````4.5T9`0`
M``#`H````````,"@````````P*````````#\`````````/P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````P*L```````#`NP```````,"[````
M````0`0```````!`!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````,`````4```!'3E4``H``P`0````!````````
M``$``<`$````"0`````````"``'`!`````$`````````!````!0````#````
M1TY5`!??P^JV9A*1((V25S_!/8"7`JWS!````!`````!````1TY5```````#
M`````@``````````````0P```%X``````````````%4`````````)P````4`
M````````3``````````]````4@```#4````E````5````%$````O````.```
M````````````7```````````````)````"8```!*````'````!X````6````
M30```$L`````````````````````````/@```#<```!9`````````$D````N
M`````````#H`````````'0```%H````8````(@```%<`````````10``````
M```"`````````%@````V````!````#P`````````1````%,```!0````,@``
M``P````_````.0```"L```!!````````````````````````````````````
M``````````````````````@```!"``````````````````````````<```!'
M```````````````-````$0```%L````4````````````````````````````
M```;````3@````D````:````$@``````````````1@``````````````````
M``8````3`````P`````````J`````````$@````M````#@```",````7````
M*0```"`````+````(0```!`````P````+````!\```!``````````#,```!/
M`````````"@```!=```````````````T``````````````!6````````````
M```5`````````#$````[````#P```$,``````````````!D````*````````
M`````````````````````````````````````````````0`````````1````
M/P````0````(````(!P0``5`!(8H`@`$@(8`A(*)`"))(`0(F(`10;H``@H`
M````/P```$(```!%````1@```$X```!/````40````````!4````50```%8`
M``!8````6@```%P``````````````&[%WQ_.WD<M:W^:?"[%F[;49-1\(?_D
M#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGSZH6Q@F4_#FVL)0]9FK\QF
MQ;F<0#CRBQQ"1=7LB0=PTS-BV^T5C"7,##J7"Z?=HVM^J9R;T67.;>"G`@IK
M&IY0"HH05Z/@^TD```````````````````````````````"F`@``$@``````
M```````````````````-`@``$@````````````````````````"-`@``$@``
M```````````````````````^`0``$@````````````````````````#H`0``
M$@````````````````````````!)`@``$@`````````````````````````!
M````(`````````````````````````"X`0``$@``````````````````````
M``!G````$@````````````````````````#%`0``$@``````````````````
M``````"4````$@````````````````````````"&`@``$@``````````````
M``````````#8`@``$@````````````````````````#]`0``$@``````````
M``````````````#2````$@````````````````````````#B````$@``````
M```````````````````P`0``$@````````````````````````!Q`0``$@``
M``````````````````````!J`0``$@````````````````````````!]`P``
M$@`````````````````````````0````(`````````````````````````"^
M`@``$@````````````````````````"K`@``$@``````````````````````
M``"]````$@`````````````````````````L````(```````````````````
M``````"=````$@````````````````````````"K````$@``````````````
M``````````"I`0``$@````````````````````````"P`@``$@``````````
M``````````````#H````%@````````````````````````#[````$@``````
M``````````````````!<`@``$@`````````````````````````6`0``$@``
M``````````````````````#)`@``$@````````````````````````":`0``
M$@````````````````````````#V`0``$@````````````````````````!%
M`0``$@`````````````````````````G`0``$@``````````````````````
M``!^`0``$@````````````````````````"8`@``$@``````````````````
M``````#7`0``$@````````````````````````"%`0``$@``````````````
M```````````N`@``$@````````````````````````!Y````$@``````````
M``````````````"3`0``$@````````````````````````",`0``$@``````
M``````````````````"<````$@````````````````````````#*`0``$@``
M```````````````````````9`@``$@````````````````````````!Z`@``
M$@````````````````````````"]`0``$@````````````````````````#9
M````$@````````````````````````#$````$@``````````````````````
M``"D````$@````````````````````````!B`0``$@``````````````````
M```````+`0``$@````````````````````````!4`0``$@``````````````
M```````````Z`@``$@````````````````````````!&````$@``````````
M``````````````#A`@``$@````````````````````````"S````$@``````
M``````````````````#1`0``$@````````````````````````"&`P``$@`0
M`(!9````````S@````````#;`P``$@`0``!0````````8`<```````!3````
M$@`0`*`C````````!`(```````#]`@``$@`0`)!$````````!0`````````;
M`P``$@`0`&!7````````(`(````````!!```$@`0`*!$````````$@(`````
M``#!`P``$``:`$#````````````````````.`P``$@`0`,!&````````(@``
M```````Q`P``$@`0`)!,````````80````````"2`P``$0`2``!@````````
M!`````````"N`P``$@`0`*!:````````GP$```````"Y`P``$@`0`(!#````
M````)0````````#6`P``$``:`)C```````````````````#O`P``$@`0`"!/
M````````UP`````````8!```$@`0``!-````````M`````````"A`P``$``9
M``#```````````````````!5`P``$@`0`/!&````````,0$```````"*````
M$0`:`$#`````````"`````````"B`0``$0`:`&#`````````"`````````#H
M`P``$``9`"C````````````````````.!```$0`9`"#`````````"```````
M``"G`P``$@`0`+XE````````*`````````#-`P``$@`0`%!:````````10``
M``````"C`P``(``9``#```````````````````",````(0`:`$#`````````
M"`````````!K`P``$@`0``!/````````'0````````!8````(@``````````
M```````````````_`P``$@`0`+!#````````UP````````!A`P``$@`0`$!<
M````````30(```````!M`@``$0`:`'#``````````0`````````@!```$@`0
M`#!(````````7`0`````````7U]G;6]N7W-T87)T7U\`7TE435]D97)E9VES
M=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`7U]L
M:6)C7W-T87)T7VUA:6X`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]A=&9O
M<FL`7U]S=&%C:U]C:&M?9F%I;`!?7V5N=FER;VX`<W1R;F-M<`!L<W1A=#8T
M`&%C8V5S<P!O<&5N9&ER`')E861D:7(V-`!S=')L96X`7U]S<')I;G1F7V-H
M:P!U;FQI;FL`8VQO<V5D:7(`<FUD:7(`4$Q?8W5R<F5N=%]C;VYT97AT`&)O
M;W1?1'EN84QO861E<@!097)L7VYE=UA3`%!E<FQ?;F5W6%-?9FQA9W,`<F5A
M9&QI;FL`4&5R;%]S=E]S971P=@!M96UC:'(`4&5R;%]S=E]S971P=FX`7U]M
M96UM;W9E7V-H:P!R96%L;&]C`&=E='!I9`!?7VUE;6-P>5]C:&L`<W1R8VAR
M`'-T<F1U<`!S=')T;VL`<W1R8VUP`'-T<G)C:'(`<W1D97)R`%]?=F9P<FEN
M=&9?8VAK`&5X:70`;'-E96LV-`!R96%D`&=E='5I9`!M:V1I<@!?7V5R<FYO
M7VQO8V%T:6]N`%]?9G!R:6YT9E]C:&L`;W!E;C8T`%!E<FQ?9W9?9F5T8VAP
M=@!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VUG7W-E
M=`!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]A=&9O
M<FM?;&]C:P!03%]D;U]U;F1U;7``4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?
M<&%R<V4`<&5R;%]D97-T<G5C=`!P97)L7V9R964`4&5R;%]S>7-?=&5R;0!P
M97)L7V%L;&]C`'!E<FQ?8V]N<W1R=6-T`'!E<FQ?<G5N`&UE;6-P>0!L:6)P
M97)L+G-O`&QI8F,N<V\N-@!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M
M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R
M<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R
M;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D
M`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`7U]B<W-?<W1A<G0`
M<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L
M:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P87)?:6YI
M=%]E;G8`1TQ)0D-?,BXQ-`!'3$E"0U\R+C,T`$=,24)#7S(N-`!'3$E"0U\R
M+C,S`$=,24)#7S(N,RXR`$=,24)#7S(N,RXT`$=,24)#7S(N,BXU`"]U<W(O
M;&EB+W!E<FPU+S4N,S@N,B]X.#9?-C0M;&EN=7@M=&AR96%D+6UU;'1I+T-/
M4D4``````0`!``$``@`#``$``0`"``0``@`"``(``0`!``(``@`!``,``@`"
M``$``0`"``(``0`%``(``P`!``$``0`!``$``0`"``(``0`"``(``0`"``(`
M`0`&``(``@`%``(``0`!``(``@`#``(``@`!``,``0`'``@``@`"``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`"``(``0`!``$``0`!``(`
M`0`"``$``0`!``$````!``<`\P(``!``````````E)&6!@``"``M!```$```
M`+21E@8```<`.`0``!`````4:6D-```&`$,$```0````LY&6!@``!0!-!```
M$````'(9:0D```0`6`0``!````!T&6D)```#`&0$```0````=1II"0```@!P
M!````````,"[````````"`````````"@)@```````,B[````````"```````
M``!@)@````````C`````````"``````````(P````````"#`````````"```
M``````#X8@```````+B_````````!@````8``````````````,"_````````
M!@````<``````````````,B_````````!@```!4``````````````-"_````
M````!@```!D``````````````-B_````````!@```%D``````````````."_
M````````$@```!X``````````````.B_````````!@```!\`````````````
M`/"_````````!@```"```````````````/B_````````!@```#L`````````
M`````$#`````````!0```%```````````````&#`````````!0```%$`````
M`````````'#`````````!0```%P```````````````B^````````!P````$`
M`````````````!"^````````!P````(``````````````!B^````````!P``
M``,``````````````""^````````!P````0``````````````"B^````````
M!P````4``````````````#"^````````!P````@``````````````#B^````
M````!P````D``````````````$"^````````!P````H``````````````$B^
M````````!P````L``````````````%"^````````!P````P`````````````
M`%B^````````!P````T``````````````&"^````````!P````X`````````
M`````&B^````````!P````\``````````````'"^````````!P```!``````
M`````````'B^````````!P```!$``````````````("^````````!P```!(`
M`````````````(B^````````!P```!,``````````````)"^````````!P``
M`!0``````````````)B^````````!P```!8``````````````*"^````````
M!P```!<``````````````*B^````````!P```!@``````````````+"^````
M````!P```!H``````````````+B^````````!P```!L``````````````,"^
M````````!P```!P``````````````,B^````````!P```!T`````````````
M`-"^````````!P```"$``````````````-B^````````!P```"(`````````
M`````."^````````!P```",``````````````.B^````````!P```"0`````
M`````````/"^````````!P```"4``````````````/B^````````!P```"8`
M``````````````"_````````!P```"<```````````````B_````````!P``
M`"@``````````````!"_````````!P```"D``````````````!B_````````
M!P```"H``````````````""_````````!P```"L``````````````"B_````
M````!P```"P``````````````#"_````````!P```"T``````````````#B_
M````````!P```"X``````````````$"_````````!P```"\`````````````
M`$B_````````!P```#```````````````%"_````````!P```#$`````````
M`````%B_````````!P```#(``````````````&"_````````!P```#,`````
M`````````&B_````````!P```#0``````````````'"_````````!P```#4`
M`````````````'B_````````!P```#8``````````````("_````````!P``
M`#<``````````````(B_````````!P```#@``````````````)"_````````
M!P```#D``````````````)B_````````!P```#H``````````````*"_````
M````!P```#P``````````````*B_````````!P```#T``````````````+"_
M````````!P```#X`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!;&?``!(A<!T`O_02(/$",,``````/\UTIT``/\EU)T`
M``\?0`#_)=*=``!H`````.G@_____R7*G0``:`$```#IT/____\EPIT``&@"
M````Z<#_____);J=``!H`P```.FP_____R6RG0``:`0```#IH/____\EJIT`
M`&@%````Z9#_____):*=``!H!@```.F`_____R6:G0``:`<```#I</____\E
MDIT``&@(````Z6#_____)8J=``!H"0```.E0_____R6"G0``:`H```#I0/__
M__\E>IT``&@+````Z3#_____)7*=``!H#````.D@_____R5JG0``:`T```#I
M$/____\E8IT``&@.````Z0#_____)5J=``!H#P```.GP_O___R52G0``:!``
M``#IX/[___\E2IT``&@1````Z=#^____)4*=``!H$@```.G`_O___R4ZG0``
M:!,```#IL/[___\E,IT``&@4````Z:#^____)2J=``!H%0```.F0_O___R4B
MG0``:!8```#I@/[___\E&IT``&@7````Z7#^____)1*=``!H&````.E@_O__
M_R4*G0``:!D```#I4/[___\E`IT``&@:````Z4#^____)?J<``!H&P```.DP
M_O___R7RG```:!P```#I(/[___\EZIP``&@=````Z1#^____)>*<``!H'@``
M`.D`_O___R7:G```:!\```#I\/W___\ETIP``&@@````Z>#]____)<J<``!H
M(0```.G0_?___R7"G```:"(```#IP/W___\ENIP``&@C````Z;#]____);*<
M``!H)````.F@_?___R6JG```:"4```#ID/W___\EHIP``&@F````Z8#]____
M)9J<``!H)P```.EP_?___R62G```:"@```#I8/W___\EBIP``&@I````Z5#]
M____)8*<``!H*@```.E`_?___R5ZG```:"L```#I,/W___\E<IP``&@L````
MZ2#]____)6J<``!H+0```.D0_?___R5BG```:"X```#I`/W___\E6IP``&@O
M````Z?#\____)5*<``!H,````.G@_/___R5*G```:#$```#IT/S___\E0IP`
M`&@R````Z<#\____)3J<``!H,P```.FP_/___R4RG```:#0```#IH/S___\E
M*IP``&@U````Z9#\____)4*<``!FD```````````55-(@^PXB7PD'$B-?"0<
M2(ET)!!(C70D$$B)5"0(2(U4)`AD2(L$)2@```!(B40D*#'`Z'C___](BS79
MFP``2(L]"IP``$B)\NBP.@``@#U[G`````^$%0$``$B+!=Z;``!D2(L`@(@Z
M!````XM$)!R->`2-6`-(8_](P><#Z*W^__](BWPD$$2+1"0<2(G!2(D%69P`
M`$B+!TB)`4B-!:,]``!(B4$(2(L%T9L``$B)01!(C060/0``2(E!&$&#^`$/
MCB,!``!(@\<(08/``[H$````#Q\`2(L'2&/R@\(!2(/'"$B)!/%$.<)UZDAC
MTDB+/>B;``!%,<!(C35.&P``2,<$T0````")VNB?^___A<`/A(<```!(BSW`
MFP``2(UL)"3H9OW__TB)[DB-/<\[``")PS'`Z$,8``!(A<!T;TB+/9>;``#H
M0OO__^B]_/__2(M$)"AD2"L$)2@````/A9@```!(@\0XB=A;7</H._S__TB)
M!62;``!(B<=(A<!T<>BG_/__2(L%L)H``&1(BQ#&@BX)````Z<+^__](BSTY
MFP``Z(3[___I:/___TB+/3";``!(A?]T"N@>-```Z7O___](C3WJ.@``2(GN
MZ*H7``!(B04+FP``2(G'2(7`#X19____Z]*Z!````.GY_O__OP$```#HX?K_
M_^C,_/__9BX/'X0``````&:0D)"0D)"0D)"0D)"0D)#S#Q[Z9I`Q[4F)T5Y(
MB>)(@^3P4%1%,<`QR4B-/<']____%1.:``#T9BX/'X0``````$B-/3&:``!(
MC04JF@``2#GX=!5(BP6^F0``2(7`=`G_X`\?@`````###Q^``````$B-/0&:
M``!(C37ZF0``2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!869``!(A<!T"/_@
M9@\?1```PP\?@`````#S#Q[Z@#T&F@```'4K54B#/6*9````2(GE=`Q(BSV&
MF0``Z`G]___H9/___\8%WID```%=PP\?`,,/'X``````\P\>^NEW____#Q^`
M`````$%72(G^3(U'.$%6055!5%532('LF`(``&1(BP0E*````$B)A"2(`@``
M,<!(B>),C8PD@````$B)UP\?@`````!!BP!-BQ!(@\<028/`"`_(B<!,B=%(
MB4?P3(G02,'I($C!Z"A)P>HX)0#_``!,"=!)B<I(P>$(2<'B&('A``#_`$6)
MTDP)T$@)R$B)1_A,.<]UK68/;TPD$&8/;UPD($B-1"1H2('":`(``&8/;U0D
M,&8/;RT7>0``#Q^``````/,/;P!F#V_B9@]O4-A(@\`09@_O2(AF#^_"9@_O
MP68/;\AF#W/0'V8/<_$!9@_KP68/;\MF#V_<9@_;Q0\I0`A(.=!UNTR+#DR+
M7A!(BWX@2(M>&$R)R$R)RDB+;@A(BTPD"$C!ZAM(P>`%2`G0`P0D2(V,"YEY
M@EJ-E#B9>8):3(G82#'82"'H2#'8C3P"2(GJ2(GH2,'H`DC!XAY)B?I("<),
MB=A)P>H;08G03#'`3"'(3#'82`'(2(GY2,'A!4P)T4R+5"001(TD"$R)R$R)
MR4C!Z0)(P>`>3XV4$YEY@EI-B>5("<A)P>T;2#'"B<%((?I,,<),`=)-B>))
MP>(%30GJ3(ML)!A!`=)(B?I(P>\"2,'B'D6)TD^-A"B9>8):2`GZ38G52#'0
MB==,(>!)P>T;2#'(3`'`38G02<'@!4T)Z$R+;"0@00'`3(G@2<'L`DC!X!Y%
MB<!*C8PIF7F"6DP)X$V)Q4@QPDG![1M!B<1,(=)(,?I(`<I,B<%(P>$%3`GI
M3(ML)"@!T4R)TDG!Z@)(P>(>B<E*C;POF7F"6DP)TDF)S4@QT$G![1M!B=),
M(<!,,>!(`?A(B<](P><%3`GO3(ML)#`!QTR)P$G!Z`)(P>`>B?]/C:0LF7F"
M6DP)P$F)_4@QPDG![1M!B<!((<I,,=),`>))B?Q)P>0%30GL3(ML)#A!`=1(
MB<I(P>D"2,'B'D6)Y$^-E"J9>8):2`G*38GE2#'02<'M&XG12"'X3#'`3`'0
M38GB2<'B!4T)ZDR+;"1`00'"2(GX2,'O`DC!X!Y%B=)/C80HF7F"6D@)^$V)
MU4@QPDG![1N)QTPAXD@QRDP!PDV)T$G!X`5-">A,BVPD2$$!T$R)XDG![`)(
MP>(>18G`2HV,*9EY@EI,">)-B<5(,=!)P>T;08G43"'02#'X2`'(3(G!2,'A
M!4P)Z4R+;"10`<%,B=!)P>H"2,'@'HG)2HV\+YEY@EI,"=!)B<U(,<))P>T;
M08G"3"'"3#'B2`'Z2(G/2,'G!4P)[TR+;"18`==,B<))P>@"2,'B'HG_3XVD
M+)EY@EI,"<))B?U(,=!)P>T;08G02"'(3#'03`'@28G\2<'D!4T)[$R+;"1@
M00'$2(G(2,'@'DC!Z0)%B>1/C90JF7F"6D@)R$V)Y4@QPDG![1N)P4@A^DPQ
MPDP!TDV)XDG!X@5-">I,BVPD:$$!TDB)^DC![P)(P>(>18G23XV$*)EY@EI(
M"?I-B=5(,=!)P>T;B==,(>!(,<A,`<!-B=!)P>`%30GH3(ML)'!!`<!,B>!)
MP>P"2,'@'D6)P$J-C"F9>8):3`G@38G%2#'"2<'M&T&)Q$PATD@Q^D@!RDR)
MP4C!X05,">E,BVPD>`'13(G22,'B'DG!Z@*)R4J-O"^9>8):3`G228G-2#'0
M2<'M&T&)TDPAP$PQX$@!^$B)STC!YP5,">],BZPD@`````''3(G`2<'H`DC!
MX!Z)_T^-I"R9>8):3`G`28G]2#'"2<'M&T&)P$@ARDPQTDP!XDF)_$G!Y`5-
M">Q&C2PB2(G*2,'I`DR+I"2(````2,'B'D@)RD^-E"*9>8):38GL2#'02<'L
M&XG12"'X3#'`3`'038GJ2<'B!4T)XDR+I"20````00'"2(GX2,'@'DC![P)%
MB=)/C80@F7F"6D@)^$V)U$@QPDG![!N)QTPAZD@QRDP!PDV)T$G!X`5-">!%
MB<!,`<)-B>A)P>T"2<'@'D&)U$T)Z$R+K"28````3#'`3"'02HV,*9EY@EI-
MB>5(,?A)P>T;2`'(3(GA2,'A!4P)Z8G)2`'(3(G12<'J`DC!X1Y!B<5,"=%-
MB<)%B<!),<I$,=),BY0DH````$J-O!>AZ]EN38GJ2`'73(GJ2<'J&TC!X@5,
M"=*)TD@!UTR)XDC!XAY)P>P"08GZ3`.$)*@```!,">))B<R)R4@#C"2P````
M23'41#'@38VD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$3(GH2<'M`DC!
MX!Y%B>!,">A)B=6)TD@#E"2X````23'%1#'O3(VL.:'KV6Y,B<%,B<=(P>\;
M2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$DQRD4QXDZ-I!*A
MZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"28G(
M2`.$),````")R4DQT$@#C"3(````13'H3HVL`*'KV6Y,B=!-B=!)P>@;2,'@
M!4P)P(G`20'%2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"30````2#''1#'G
M3(VD.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$B>=,
M"=%)B<*)P$@#A"38````23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B!4P)
MTHG220'53(G"2<'H`DC!XAY%B>I,"<))B<B)R4DQT$@#C"3@````13'@3HVD
M`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$2(GX2,'O`DC!X!Y%B>!("?A(
MB=>)TD@#E"3H````2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)
M20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$@#A"3P````23'*13'B3HVD$J'K
MV6Y(B?I)B?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<B)
MR4DQT$4QZ$Z-K`"AZ]EN3(G038G02,'@!4G!Z!M(`XPD^````$P)P(G`20'%
M2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"0``0``2#''1#'G3(VD.:'KV6Y,
MB<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$B>=,"=%)B<*)P$@#
MA"0(`0``23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'53(G"
M2<'H`DC!XAY%B>I,"<))B<B)R4DQT$4QX$Z-I`"AZ]EN3(G038G02<'H&TC!
MX`5,"<!(`XPD$`$``(G`20'$2(GX2,'O`DC!X!Y%B>!("?A(B=>)TD@#E"08
M`0``2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G12<'J
M`DC!X1Y$B>],"=%)B<*)P$@#A"0@`0``23'*13'B3HVD$J'KV6Y(B?I)B?I)
MP>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<B)R4DQT$4QZ$Z-
MK`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q4B)^$C!X!Y(P>\"18GH2`.,
M)"@!``!("?A(B=>)TD@#E"0P`0``2#''1#'G38G$2(V,.:'KV6Y,B<=)P>P;
M2,'G!4P)YTV)U$G!Z@))P>0>B?]-"=1)B<)(`?F)P$TQXHG/2`.$)#@!``!%
M,>I)B?U.C902H>O9;DB)^DG![1M(P>(%3`GJ00'23(G"2<'H`DC!XAY%B=),
M"<)-B>!%B>1),=!)B=9!B=5$,<%-B=!(C8P(H>O9;DR)T$G!Z!M(P>`%3`G`
M1(T$`4B)^4C![P*XW+P;CTC!X1Y("?E)"<Z)ST@A^DTAUDD)UDB+E"1``0``
M2`'"3`'B38G$3`'R38G&2<'D!4G![AM-"?1!`=1,B=))P>H"2,'B'D6)Y$P)
MTD@)T4F)UD&)TDDA_DPAP4P)\4R+M"1(`0``20'&30'U38GF3`'I38GE2<'N
M&TG!Y05-"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPAPDP)
M\DR+M"10`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG![`)(
MP>(>B?],">)("=%)B=9!B=1-(<9,(>E,"?%,B[0D6`$``$D!QDT!\DF)_DP!
MT4F)^DG![AM)P>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)"<Y)
M(?Y,(>I,"?),B[0D8`$``$D!QDT!\$V)UDP!PDV)T$G!X`5)P>X;30GP00'0
M2(GZ2,'O`DC!XAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+M"1H`0``20'&
M30'T38G&3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)Y$P)
MT4&)RDD)SDTAQDPATDP)\DR+M"1P`0``20'&30'U38GF3`'J38GE2<'N&TG!
MY05-"?5!`=5,B<)(P>(>2<'H`D6)[4P)PD@)T4F)UD&)T$TAUDPAX4P)\4R+
MM"1X`0``20'&3`'W38GN2`'Y3(GO2<'N&TC!YP5,"?=)B=8!STR)X4G![`)(
MP>$>B?],">%!B<Q)"<Y-(>Y,(>),"?),B[0D@`$``$D!QDT!\DF)_DP!TDF)
M^DG![AM)P>(%30GR00'23(GJ2<'M`DC!XAY%B=),">I("=%)B=9!B=5((?E-
M(>9,"?%,B[0DB`$``$D!QDT!\$V)UDP!P4V)T$G![AM)P>`%30GP28G600'(
M2(GY2,'O`DC!X1Y%B<!("?F)STD)SDTAUD@A^DP)\DR+M"20`0``20'&30'T
M38G&3`'B38G$2<'N&TG!Y`5-"?1!`=1,B=))P>H"2,'B'D6)Y$P)TD@)T4F)
MUD&)TDDA_DPAP4P)\4R+M"28`0``20'&30'U38GF3`'I38GE2<'N&TG!Y05-
M"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPAPDP)\DR+M"2@
M`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG![`)(P>(>B?],
M">)("=%)B=9!B=1-(<9,(>E,"?%,B[0DJ`$``$D!QDT!\DF)_DP!T4F)^DG!
M[AM)P>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)"<Y)(?Y,(>I,
M"?),B[0DL`$``$D!QDT!\$V)UDP!PDV)T$G![AM)P>`%30GP00'02(GZ2,'O
M`DC!XAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+M"2X`0``20'&30'T38G&
M3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)Y$P)T4D)SD&)
MRDTAQDPATDP)\DR+M"3``0``20'&30'U38GF3`'J38GE2<'N&TG!Y05-"?5!
M`=5,B<))P>@"2,'B'D6)[4P)PD@)T4F)T$&)UTTAT$PAX4P)P4R+A"3(`0``
M20'`3`''38GH2`'Y3(GO2<'H&TC!YP5,"<=$C00Y3(GG2<'L`DB)T4C!YQY,
M">=!B?Q("?E,(>E,(>)("<I(BXPDT`$``$@!P4P!T4V)PD@#A"38`0``2`'*
M3(G!2<'J&TC!X05,"=&)R4@!RDR)Z4G![0)(P>$>08G23`GI2`G/28G-08G.
M3"''32'E20G]2HT\.$R)T$R+O"3X`0``3`'O38G52,'@!4G![1M,">B)P$@!
MQTR)P$G!Z`)(P>`>08G]20G`N-;!8LI,,<$QT4B+E"3@`0``2`'"3`'B38GL
M2`'*3(GI2<'L&TC!X05,">%-B=2)R4G!Y!Y(`<I)P>H"20''30GB38G$B=%%
MB<!-,=1$,>=,BZ0DZ`$``$D!Q$T!]$F)SDP!YTF)S$G![AM)P>0%30GT38GN
M2<'M`DG!YAY%B>1-"?5,B[0D\`$``$P!YT&)_$D!QDT!\$V)UDTQ[D0Q\DV)
MYDD!T$R)XDG![AM(P>(%3`GRB=))`=!(B<I(P>D"2,'B'D6)QD@)RD2)T4V)
MZDDQTDP!^4R+O"0``@``1#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,"=&)R4@!
MSTR)X4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD$`(``$4QZ$V)
MU4D!R$R)T4G![1M)`<=(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)\4R+
MM"0(`@``20'&3`'R38GF23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,"?*)TD@!
MUTR)TDG!Z@)(P>(>08G^20G21(GB28G,B<E,`?I-,=1,B[PD(`(``$4QX$V)
M]$D!T$R)\DG![!M)`<=(P>(%3`GBB=))`=!,B>I)P>T"2,'B'D6)Q$P)ZDR+
MK"08`@``20'%3`'I38G523'51#'O38GE2`'/3(GA2<'M&TC!X05,">F)R4@!
MSTR)\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD,`(``$4QT$V)
MZDD!R$R)Z4G!ZAM(P>$%3`G1B<E)`<A,B>%(P>$>2<'L`D6)PDD!QTP)X4R+
MI"0H`@``20'$3`'B38GT23',1#'G38G42`'73(G22<'L&TC!X@5,">*)TD@!
MUTR)ZDG![0)(P>(>08G\20G51(GR28G.B<E-,>Y,`?I,B[PD0`(``$4Q\$V)
MYDD!T$R)XDG![AM(P>(%3`GRB=))`=!,B=))P>H"2,'B'D6)QDP)TDR+E"0X
M`@``20'"3`'138GJ23'21#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,"=&)R4@!
MSTR)X4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD8`(``$4QZ$V)
MU4D!R$R)T4G![1M(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)\4R+M"1(
M`@``20'&3`'R38GF18GD23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,"?*)TD@!
MUTR)TDG!Z@)(P>(>08G^20G22(N4)%`"``!(`<))`=1(B<J)R4PQTDD!QT0Q
MPDV)\$D!U$R)\DG!Z!M(P>(%3`G"B=))`=1,B>I)P>T"2,'B'D6)X$P)ZDR+
MK"18`@``20'%3`'I38G523'51#'O38G%2`'/3(G!2<'M&TC!X05,">F)R4@!
MSTR)\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD<`(``$4QXDV)
M[$P!T4V)ZDG![!M)P>(%30GB38G$18G22<'D'DP!T4G!Z`))`<=-">!,BZ0D
M:`(``$&)RDD!Q$@#A"1X`@``3`'B38GT3`'(33'$1#'G38G42`'73(G22<'L
M&TC!X@5,">)-B>Q)P>T"2<'D'HG230GE18GT38G&2`'733'NB?I-`?Q%B<!$
M,?%)B=9,`<!-B>A,`>%)B=1)P>X;2<'D!4T)]$0!X4V)U$G!Z@))P>0>B<E-
M">)-,=!$,<=)B<A(`?A(B<](P><%2<'H&P'I00':3`G'1`-N($B)3@@!^$R)
M5AA(B09(B=!(P>H"2,'@'DR);B!("=!$`=A(B4802(N$)(@"``!D2"L$)2@`
M``!U$DB!Q)@"``!;74%<05U!7D%?P^A6Y?__9@\?1```05=!5D%505154TB#
M[`A(A?\/A+$```!,BS4"@P``387V#X2A````#[8'28G_28GUA,!T!#P]=5A%
M,>1)BQY(A=MT,TUCY$R)]0\?@`````!,B>),B?Y(B=_H,N/__X7`=0="@#PC
M/71'2(M="$B#Q0A(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```````28G\
M00^V1"0!28/$`83`=`0\/77N12G\ZY%F#Q]$``!,*?5*C5PC`4C!_0-!B6T`
MZ[1F#Q]$```QV^NJ#Q]``%-(B?M(@>R@````9$B+!"4H````2(F$))@````Q
MP$B)YNB*Y/__A<!U-HM4)!B!X@#P``"!^@!```!T"('Z`*```'4>O@(```!(
MB=_HS^3__X7`#Y3`#[;`ZP</'T0``#'`2(N4))@```!D2"L4)2@```!U"4B!
MQ*````!;P^C]X___9F8N#Q^$``````!FD$%6055!5%532('LH````&1(BP0E
M*````$B)A"28````,<!(A?]T"(`_`$B)^W4Q2(N$))@```!D2"L$)2@````/
MA1D!``!(@<2@````6UU!7$%=05[#9BX/'X0``````.BKXO__28G$2(7`=,),
MB>?H>^3__TB%P`^$H@```(!X$RY(C6@3=0B`?0$`=-]FD(!X$RX/A)X```!(
MB=_H3N+__TB)[TF)Q>A#XO__18UT!0)-8_9,B??H@^'__TF)Z4F)V$R)\DF)
MQ4B)Q[X"````,<!(C0VJ(```Z*'C__],B>](B>;H%N+__TR)[X/X_W00BT0D
M&"4`\```/0!```!T5NAIX?__3(GOZ-'A__],B>?HV>/__TB%P`^%7O___TR)
MY^A(X___2(G?Z%#A___I^O[__P\?`(!]`2X/A5C___^`?0(`#X0A____Z4G_
M__\/'X``````Z*/^___KJ.B,XO__9F8N#Q^$``````"04TB+'>A_``!(C0UQ
M8```2(TU!"```$B+%=M_``!D2(L[Z!KC__]D2(L[13')6TR-!9\A``!(C14T
M%P``3(G!2(TU\!\``.F%X?__#Q]$``!!54%455-(@>P`$```2(,,)`!(@^P8
MNO\/``!D2(L$)2@```!(B80D"!```#'`28GD2(G[2(GU2(T]O1\``$R)YNB*
MX?__A<!^$HG!@^@!2&/0@#P4`'5(A<!U/$B+!3U_``!(B>I(B=YD2(LXZ%[@
M__](BX0D"!```&1(*P0E*````'5.2('$&!```%M=05Q!7<,/'T0``(G!9@\?
M1```3&/IOB\```!,B>=,B>KH;=___TB%P'2D2(L%X7X``$R)Z4R)XDB)WF1(
MBSCH[^#__^N?Z%CA__\/'X0``````$%7059!54%454B)]5-(B?M(@^PH9$B+
M!"4H````2(E$)!@QP#'`@#X]#Y3`2`'%2(GOZ!G@__](C70D%$B)WTF)Q#'`
MZ+?[__](A<`/A`X!``!(B<=)B<7H\]___TPYX`^#V@```$QC1"043HTTQ0``
M```/M@.$P`^$P@$``#P]#X2Z`0``2(G8#Q^```````^V4`%(@\`!A-)T!8#Z
M/77O2"G82)A,BRUS?@``2HU\(`+HZ=[__TT!]4F)10!(A<!T5DB+!59^``!(
MC4L!2HL4,`^V`X@"/#UT(H3`=0WK'`\?@``````\/701#[8!2(/"`4B#P0&(
M`H3`=>O&`CTQP&8/'T0```^V3`4`B$P"`4B#P`&$R77O2(M$)!AD2"L$)2@`
M```/A2<!``!(@\0H6UU!7$%=05Y!7\,/'T``,<!F#Q]$```/ME0%`$&(5`4`
M2(/``832=>[KO0\?0`!,BSVY?0``28,_``^$U@```$R)^$4Q[68/'X0`````
M`$B#P`A$B>I!@\4!2(,X`'7O1(UR`TUC]DJ-#/4`````BP6R?0``A<!U9DB)
MSTB)3"0(QP6<?0```0```.C?W?__2(G'2(7`#X1,____36/%2(M,)`A,B?Y.
MC33%`````$R)\N@XX/__2(D%,7T``$B)QT&-10%$B6PD%$B82,<$QP````#I
M:?[__V8/'T0``$R)_TB)SNCEW___2(D%_GP``$B)QTB%P`^$Z_[__TUCQ4Z-
M-,4`````Z[</'T0``#'`Z5_^__^Y$````$4Q[>E,____Z/?>__\/'X``````
M2(L%67P``$B+%5I\``!(C0W;7```2(TU;AP``&1(BSCIB]___V9F+@\?A```
M````05154TB![``0``!(@PPD`$B![``0``!(@PPD`$B#["!D2(L$)2@```!(
MB80D&"```#'`2(V<)!`0``!(B>7H/=W__TR-#4P<``"Z`1```$B)WT&)P$B-
M#3X<``"^`@```#'`Z.C>__](B=^Z`!```$B)[NCHW?__,?^%P'@R1(U@`4B)
MPTUCY$R)Y^B`W/__2(G'2(7`=!A(8]M,B>%(B>Y(B=KHQ]S__\8$&`!(B<=(
MBX0D&"```&1(*P0E*````'4/2('$("```$B)^%M=05S#Z.G=__]F#Q^$````
M``#I&____V9F+@\?A```````05=!5D%505154TB![``0``!(@PPD`$B![+@`
M``!D2(L$)2@```!(B80DJ!```#'`28G\2(GS2(T]>QL``$B-="0,Z#GX__^^
M+P```$R)YTB)Q>@IW?__2(7`=$0QP$R)YDB-/5D;``#H$_S__TR)X$B+E"2H
M$```9$@K%"4H````#X6&`0``2('$N!```%M=05Q!74%>05_##Q^``````$B)
MWTR-+20;``!,C34C'```Z/K<__],B>Y(B<?H+]W__TB)PTB%P'23@#L`#X3D
M````9@\?1```2(7M=!-(B=Y(B>_H^-S__X7`#X2G````2(G?Z-C;__](C50#
M_TF)QT@YTW(7ZR5F#Q^$``````#&`@!(@^H!2#G3=`6`.B]T[TB)W^BGV___
M28G'3(GGZ)S;__])C40'`4@]_P\```^'%____TR-O"2@````3(GQ28G8,<!(
M@^P(N@`0``"^`@```$R)_T%43(T-81H``.CLW/__2(UT)"!,B?_H7]O__UI9
MA<!U$(M$)"@E`/```#T`@```=$E,B>XQ_^A/W/__2(G#2(7`#X2O_O__@#L`
M#X4B____2(7M=`:`?0`N=!=!OP$```!(C1WH&0``Z5G___\/'T0``(!]`0!T
MN>OAO@$```!,B?_H@]S__X7`=:9,B?Y(C3W&&0``Z(#Z__],B?_HJ-O__^EC
M_O__Z+[;__]F9BX/'X0```````\?`%.^+P```$B)^^@2V___2(U0`4B%P$@/
M1=I(B=];Z6[;__]F9BX/'X0```````\?`%532('L`!```$B##"0`2(/L&&1(
MBP0E*````$B)A"0($```,<!(A?\/A,H```"`/P!(B?L/A+X```#H0=K__TB-
M4`%(@?H`$```#X?8````2(GE2(GO@_H(<@Z)T4B)WL'I`_-(I4B)\S')]L($
M=`F+"XD/N00```#VP@)T#D0/MP0+9D2)!`](@\$"@^(!=`</MA0+B!0/2(U$
M!?](.<5R$NL5#Q]``,8``$B#Z`%(.>AT!8`X+W3OOB\```!(B>_H*MK__TB%
MP'0M2#G%<E!(B>_HB-K__TB+E"0($```9$@K%"4H````=4%(@<08$```6UW#
M#Q\`2(N$)`@0``!D2"L$)2@```!U(4B!Q!@0``!(C3U-&```6UWI0-K__\8`
M`.NK#Q\`,<#KK.A/VO__9F8N#Q^$```````/'T``05=!5D%505152(TM,A@`
M`%-(@^P89$B+!"4H````2(E$)`@QP$B-7"0$9@\?1```,<!(B=Y(B>_HL_3_
M_TB%P'0V2&-4)`1(BP7"=P``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(
MB1!(A=)U\.N^9@\?1```2(TMS!<``)`QP$B)WDB)[^AC]/__2(7`=#9(8U0D
M!$B+!7)W``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF
M#Q]$``!(C2V$%P``D#'`2(G>2(GOZ!/T__](A<!T-DAC5"0$2(L%(G<``$B-
M!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-+3T7
M``"0,<!(B=Y(B>_HP_/__TB%P'0V2&-4)`1(BP72=@``2(T$T$B+4`A(B1!(
MA=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(TM]!8``)`QP$B)WDB)
M[^AS\___2(7`=#9(8U0D!$B+!8)V``!(C0302(M0"$B)$$B%TG329I!(BU`0
M2(/`"$B)$$B%TG7PZ[YF#Q]$``!,C26T%@``D#'`2(G>3(GGZ"/S__](A<!T
M-DAC5"0$2(L%,G8``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72
M=?#KOF8/'T0``$R-)1D6``"0,<!(B=Y,B>?HT_+__TB%P'0V2&-4)`1(BP7B
M=0``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```
M3(TU(!8``)`QP$B)WDR)]^B#\O__2(7`=#9(8U0D!$B+!9)U``!(C0302(M0
M"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!,C2W:%0``D#'`
M2(G>3(GOZ#/R__](A<!T-DAC5"0$2(L%0G4``$B-!-!(BU`(2(D02(72=-)F
MD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$R-/905``"0,<!(B=Y,B?_HX_'_
M_TB%P'0V2&-4)`1(BP7R=```2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(
MB1!(A=)U\.N^9@\?1```3(T]XA0``)`QP$B)WDR)_^B3\?__2(7`=#9(8U0D
M!$B+!:)T``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF
M#Q]$``!(B=Y(C3W[%```Z$GQ__](A<!T#4B)QDR)[S'`Z#?U__\QP$B)WDB-
M/>D4``#H)O'__TB%P'012(G&2(T]YQ0``#'`Z!#U__](B=Y(C3WA%```,<#H
M__#__TB)QDB%P'0Y3(GG,<#H[?3__TB+1"0(9$@K!"4H````=41(@\082(GO
M2(TURQ0``#'`6UU!7$%=05Y!7^F^]/__,<!(B=Y(C3V=%```Z*WP__](A<!T
MNTB)QDR)]S'`Z)OT___KK.CDU?__#Q]``$B#[!A(C3T4%```9$B+!"4H````
M2(E$)`@QP$B-="0$Z&OP__](A<!T+@^V$(#Z,`^4P(32#Y3""="#\`$/ML!(
MBU0D"&1(*Q0E*````'4,2(/$&,,/'P`QP.ODZ'_5__]F9BX/'X0```````\?
M0`!06$B![-@```!(B70D*$B)5"0P2(E,)#A,B40D0$R)3"1(A,!T-P\I1"10
M#RE,)&`/*50D<`\IG"2`````#RFD))`````/*:PDH`````\IM"2P````#RF\
M),````!D2(L$)2@```!(B40D&#'`2(GZ2(V$).````!(B>%(BSW><@``2(E$
M)`B^`@```$B-1"0@QP0D"````,=$)`0P````2(E$)!#H]M/__[__````Z,S2
M__]F9BX/'X0``````)!!5%533(V<)```__](@>P`$```2(,,)`!,.=QU[TB#
M[!"Z`@```#'V9$B+!"4H````2(F$)`@``0`QP$&)_$B)X^C:U/__2(UH_TB)
MZDC!^C](P>HP2(U$%0`/M\!(*=!(*<4/B*L````/'X``````,=)(B>Y$B>?H
MH]3__TB#^/\/A*0```"Z"``!`$B)WD2)Y^A)TO__@_C_#X1]````2)A(@_@'
M=EA(C40#^$@YV').2(T5EW$``.L.#Q]$``!(@^@!2#G8<C=(BPI(.0AU[T@I
MV$@!Z$B+E"0(``$`9$@K%"4H````=4](@<00``$`6UU!7,-F+@\?A```````
M2('M```!`$B!_0``__\/A5S___](Q\#_____Z[I(C3U'$@``,<#H%?[__TB-
M/2P2```QP.@'_O__Z'+3__]FD$B#[`CHI]/__XG'Z##2__](A<!T`TB+`$B#
MQ`C##Q\`059!54%43(TE"A(``%5(B?U,B>=32(/L$&1(BP0E*````$B)1"0(
M,<!(C70D!.C-[?__2(7`=`B`.`!(B<-U,$B+1"0(9$@K!"4H````#X5^````
M2(GN2(/$$$R)YS'`6UU!7$%=05[ID_'__P\?`$B)[^C8T?__2(G?28G%Z,W1
M__]-C70%`DR)]^@0T?__2(/L"$R)\DF)Z%-(B<=)B<5,C0VF$```2(T-I1$`
M`+X"````,<#H)=/__UA:2(M$)`AD2"L$)2@```!U!4R)[NN%Z'G2__]F#Q^$
M``````!!5TB-#441``!!5F9(#V[!2(T-TA```$%505154TB![$@!``!(B7PD
M"$B-;"0D2(T](Q```$B)[F1(BP0E*````$B)A"0X`0``2(T%!A```$C'1"1@
M`````$C'A"28`````````$C'1"1``````&9(#V[(2(T%V1```&8/;,%F2`]N
MT$B-!=$0```/*40D4&9(#V[!9D@/;MA(C0UF$```9@]LPDB-!;D0```/$40D
M>&9(#V[!9D@/;N!(C0V>$```9@]LPS'`#Q&$)(@```!F2`]NP68/;,0/*40D
M,.@^[/__2(7`=`R`.`!(B<,/A=T$``#HN-'__XG'Z$'0__](A<`/A!@$``!,
MBSA-A?\/A`P$``!,B?_H5-#__TR-=``!3(GW38GTZ)3/__]%#[8'2(E$)!!(
MB<-%A,!T6$R-+2D0```/'T``3(GR10^VP$B)WS'`3(GIO@(```!)@\<!Z)O1
M__]-.?1,B?)%#[8'20]#U$B)T$PI\$B#P`)(.=!(#T+"22G62(/#`DV-=`;^
M183`=;-,C6PD<$B-/4\/``#K$@\?1```28M]"$F#Q0A(A?]T.TB)[C'`Z&'K
M__])B<1(A<!TX8`X`'3<2(G'Z!SL__^%P'303(GGZ'#0__])B<1(A<!U2`\?
MA```````3(UL)%!-BV4`387D=#)!@#PD``^$#P,``$R)Y^C?Z___A<`/A0\!
M``!-BV4(28/%"$V%Y'789BX/'X0``````$R)Y^@XS___2(M<)!!)B<5(B=_H
M*,___T6-M`4$!```36/V3(GWZ&7.__]338G@3(T-"@X``$F)Q4B-!0L/``!,
MB?*^`@```%!(C0WR#@``3(GO,<#H=M#__TR)[[[``0``Z.G0__]?05B#^/]U
M$NB<S___1(L(08/Y$0^%[`(``$B-A"2@````3(GO2(G&2(E$)!#HU\___XG#
MA<!T>4B+1"0(38GH2(L]@FT``$B-%4L/``"^`@```$B+"#'`Z'S-__]%,>1(
MBX0D.`$``&1(*P0E*`````^%/P0``$B!Q$@!``!,B>!;74%<05U!7D%?PP\?
M1```3(GG28/%".@<S___28G$2(7`#X2U_O__Z>O^__\/'P"+A"2X````)0#P
M```]`$````^%</___T2+I"2\````Z$3/__]!.<0/A5K___^+A"2X````)?\!
M```]P`$```^%0____TR)]^@LS?__2(GN2(T]I`T``$F)Q#'`Z'CI__](A<`/
MA%\"``!(BTPD"$B)QDB+.>C?\/__28G'2(7`#X1#`@``3(G_Z)O-__](B<*#
M^`-^0TB82(TUF@T``$B)5"0828U\!_SHB\[__X7`=2=(BU0D&(/Z!`^$]P(`
M`(U"^TB808`\!R\/A.<"``!F#Q^$``````!(B>Y(C2V%#```,<!(B>_H[.C_
M_TB%P`^$XP$```^V`(3`#X38`0``/#`/A-`!``!(B>](C37"#```,<#HO^S_
M_TB-+5P-``!,C3U##0``Z+S,__]53(GR3(T-\0L``%!-B>A(C0T:#0``O@(`
M``!,B><QP.AGSO__6%KK/P\?`.B;S?__@S@1=43H@<S__X/#`4B#[`A-B>A5
M3(T-KPL``$R)^4R)\E.^`@```$R)YU`QP.@HSO__2(/$(+[``0``3(GGZ)?.
M__^#^/]TLDR)[^AJS/__3(GF2(T]6`L``#'`Z!GL__],B>?H$?K__^GC_?__
M#Q]``$4QY.D0_?__2(M\)#!(C5PD,$B%_W0BD#'`2(GNZ.;G__](A<!T!8`X
M`'5$2(M["$B#PPA(A?]UW[\-````0;P-````3(T]Y`L``$&^#0```.A2R___
M0;A3````2(E$)!!(B</IO/O__P\?@`````!(B<?HP,S__TF)QTB%P'2LZ7?[
M__](BT0D"$V)Z$B+/;1J``!(C14]#```O@(```!(BP@QP.BNRO__Z2W]__]F
M#Q^$``````!(B<?H2/G__TB+A"0X`0``9$@K!"4H````#X5>`0``2('$2`$`
M`$B)WUM=05Q!74%>05_I2,S__P\?A```````2(M$)`A,BSCIL/W__P\?`$R)
M_S'V,<#HQ,O__T&)QX7`#X09_O__B<?H@O?__TB%P`^("?[__S'22(UP]D2)
M_TB)1"0(Z(;,__](C70D*KH&````1(G_Z#3*__](BTPD"$B#^`8/A=<```"!
M?"0J`$-!0P^%Q_W__V:!?"0N2$4/A;K]__\QTDB-<<Y$B?_H/,S__TB+7"00
MNB@```!$B?](B=[HY\G__TB#^"@/A8\```!(C07Z"@``O@(```!-B>A,B?+&
MA"3(`````$B-#;$*``!,C0V%"0``3(GG4#'`4^@)S/__65[I\/W__TB+1"0(
M2(M0"$B%T@^$$/W__TB)UTB)5"0(Z%/*__](@_@##X;Y_/__2(M4)`A(C352
M"@``2(U\`OSH0\O__TB+5"0(A<!,#T3ZZ=/\___H'LO__TB-/3$*```QP.B@
M]?__051(C3TJ"0``55-(@^P02(L=:F@``&1(BP0E*````$B)1"0(,<!,C60D
M!$R)YF1(BRL/MH6P````B(6Q````,<#H>N7__TB%P'0)@#@Q#X1D`0``,<#H
M=?#__V1(BRM(B>^Y`P```+H!````2(TU\`D``.@(R?__2(G%2(7`="A(BT`0
M9$B+.TB-%=8)``!(BS#H&<G__TB+11!(BS#V1@Y`#X5(`0``9$B+.[D#````
MN@$```!(C36M"0``Z+[(__](B<5(A<!T+4R)YDB-/2T(```QP.CEY/__2(G"
M2(7`#X3I````2(M%$&1(BSM(BS#HN<C__V1(BSNZ`0```$B--64)``#HU,?_
M_V1(BSM(C15J"0``2(G&Z)'(__]D2(L#3(GF2(T]RP<``,:`L0`````QP.B%
MY/__2(D%YF<``$B)PTB%P'0^OL`!``!(B=_HR<K__XU0`8/Z`78)@_@1#X66
M````2(M$)`AD2"L$)2@````/A9\```!(@\006UU!7,,/'P!(BSVA9P``Z`SW
M__](B06-9P``2(G#2(7`=:=(C3U^"0``,<#HK\G__P\?@`````"`>`$`#X2=
M_O__Z8W^__]F#Q^$``````!(BP599P``2(LP2(M%$$B+..CZYO__Z0S___\/
M'T0``&1(BSOH!\G__^FJ_O__B<%(BP4I9P``2(G:2(T]/PD``$B+,#'`Z$7)
M___H\,C__U532(G[2(T](P<``$B#[!AD2(L$)2@```!(B40D"#'`2(UT)`3H
M=N/__TB%P'0<#[80@/HP#Y3`A-(/E,((T'4*2(7;=`6`.P!U'4B+1"0(9$@K
M!"4H````=6Y(@\086UW#9@\?1```2(G?Z`#M__^^+P```$B)QTB)Q>C@Q___
M2(U0`4B%P$@/1>I(B>_H/<C__[H$````2(TU7`<``$B)Q^B)QO__A<!UH$B+
M1"0(9$@K!"4H````=0Y(@\082(G?6UWI-^3__^@BR/__9I!(@^P(OX````#H
M8L;__V8/;P4J1@``2,=`,``````/$0!F#V\%)T8``,=`>``````/$4`09@]O
M!21&```/$4`@2(/$",-F9BX/'X0``````$%72&/"059)B<9!54%428G\54B-
M;SA32(GS2(/L"$B+=RA(BU<PC0S&2#GQ2(E/*$B#T@!(P>@=2`'02(E',$AC
M1WB%P`^%[0```$&#_C\/CBL!``!!@^Y`18GW0<'O!D6-;P%)P>4&20'=#Q]$
M``#S#V\#3(GG2(/#0`\110#S#V]+T`\131#S#V]3X`\152#S#V];\`\173#H
M<<O__TPYZW7,0<'G!D4I_DECQDB#^`AR7$F+50!)C4PD0$B#X?A)B50D.$F+
M5`7X2(E4!?A(*<U(`>A)*>U(@^#X2(/X"'(82(/@^#'228MT%0!(B3012(/"
M"$@YPG+N18ET)'A(@\0(6UU!7$%=05Y!7\.0J`1U=$B%P'3B00^V50!!B%0D
M.*@"=-1!#[=4!?YFB50%_NO'#Q]``$&_0````$B-?`4`2(G>02G'13GW10]/
M_DUC[TR)ZNAEQ___08M$)'A$`?A!B40D>(/X0'633(GG12G^3`'KZ)7*___I
MR_[__TF)W>DC____08M5`$&)5"0X08M4!?R)5`7\Z5S___^0059,C78X055!
M5%5(B?U33(MN*$B)\TR+9C!,B>A(P>@#@^`_C5`!QD0&.(!(8\J#^C@/CH`!
M``"^0````$P!\2G6=`\QP(G"@\`!Q@01`#GP<O-(B=_H%<K__V8/[\`/$4,X
M2<=&,`````!!#Q%&$$$/$48@3(GB00^VQ4R)[TR)[DC!ZAA(P>`(3(GA2,'O
M$$F)T$R)ZDC![A@/MM9`#[;_0`^V]DC!Z1!("=!,B>(/MLE(P>`(2`GX#[;^
M00^VT$C!X`A("?!!#[;T2,'@"$@)\$C!X`A("?A(B=](P>`(2`G(2,'@"$@)
MT$B)0W#H?,G__TB+`TB)WTC!Z!B(10!(BP-(P>@0B$4!2(L#B&4"2(L#B$4#
M2(M#"$C!Z!B(101(BT,(2,'H$(A%!4B+0PB(909(BT,(B$4'2(M#$$C!Z!B(
M10A(BT,02,'H$(A%"4B+0Q"(90I(BT,0B$4+2(M#&$C!Z!B(10Q(BT,82,'H
M$(A%#4B+0QB(90Y(BT,8B$4/2(M#($C!Z!B(11!(BT,@2,'H$(A%$4B+0R"(
M91)(BT,@B$436UU!7$%=05[I;,/__P\?0`"X.````$D!SC'_*="#^`AR1TF-
M3@B)PDG'!@````!)QT06^`````!(@^'X22G.1`'P@^#X@_@(#X*`_O__@^#X
M,=*)UH/""$B)/#$YPG+SZ6G^__\/'T``J`1U)(7`#X19_O__0<8&`*@"#X1-
M_O__,=)F08E4!O[I0/[__P\?`$''!@````!!QT0&_`````#I*/[__P\?`)"0
MD)"0D)"0D)"0D)"0\P\>^I"02(L-76$``.G@P?__\P\>^DB#[`A(@\0(PP``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!)
M;G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R]S96QF+V5X90`O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@`Q`&QS965K(&9A:6QE9`!R96%D(&9A:6QE
M9`!,1%],24)205)97U!!5$@`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%
M4@!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`<&%R;``N<&%R`'-H;W)T
M(')E860`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE
M=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#8S`"UE
M`"TM`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O(&-R96%T92!C86-H
M92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A
M8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````````
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D
M8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2
M+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*
M)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S
M7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*
M;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE
M(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@
M)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@
M;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@
M)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H
M*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?
M34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D
M8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R
M;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64[
M"G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P
M,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL
M(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI
M.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?
M<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S
M96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@
M>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO
M=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C
M(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA
M<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?
M1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD
M(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P
M;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A
M9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B
M7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C
M:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H
M92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,
M15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I
M.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T
M(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@
M+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?
M1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B
M+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B
M=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M
M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L
M;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@
M7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF
M+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M
M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U
M<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE
M?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII
M9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W
M*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#
M86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD
M9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T
M=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I
M;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@
M/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD
M(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA
M;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*
M;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II
M<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@
M*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@
M)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P
M87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N
M7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=
M(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%
M55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E
M:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=6
M6S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF
M("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G
M02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L
M92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G
M86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS
M:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE
M('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D
M,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD[
M"FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG
M4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O
M<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG
M('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII
M9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY
M;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>
M7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I]
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I
M<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#
M.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H
M+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H
M9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D
M;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D
M;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O
M=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R
M96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,
M;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!8
M6%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D[
M"FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS
M92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<
M421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q
M*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD
M?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C
M:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S
M92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT
M+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D
M;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7
M<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R
M:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]
M"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB
M*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T
M>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@
M/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X]
M(")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@
M)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L
M;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B
M.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F
M:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH
M*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@
M7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H
M:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@
M>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E
M>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I
M;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L
M<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H
M)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE
M(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"([
M"GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP
M87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O
M9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`
M05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D
M97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN
M*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H
M)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E
M<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q
M=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R
M:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@
M0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I
M<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER
M92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R
M97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@
M871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U
M:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![
M(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E
M<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@
M>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP
M9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U
M<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER
M.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD
M)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L
M96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E
M96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG
M=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H
M+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C
M86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@
M*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[
M4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C
M86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-
M4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`
M7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H
M+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B
M.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H
M<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L
M("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE
M+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D
M9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O
M*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*
M:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[
M4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA
M;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S
M>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA
M;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T
M=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?
M<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!
M4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S
M+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@
M+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?
M<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!
M345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@
M>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@
M)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I
M"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H
M*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<
M+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E
M;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E
M='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-
M4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[
M4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*
M:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP
M<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I
M9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP
M86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE
M.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@
M)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``$-!0TA%``!P97)L>'-I+F,`````
M````_____P````#_____``````$C16<`````B:O-[P````#^W+J8`````'94
M,A``````\.'2PP````````````````$;`SO\````'@```&!___\P`0``T(+_
M_U@!``#@@O__A`8``/Z$__\8`0``\(7__W`!``!@G/__P`$``#"=__\,`@``
MP)W__S`"```PG___=`(``("?__^0`@``8*#__]`"``#`HO__'`,``/"B__\P
M`P``T*/__VP#``#@H___@`,```"F___D`P``,*;__P`$``!PI___/`0``-"K
M__^(!```0*S__Z0$````K?__P`0``$"N__\`!0``8*[__Q@%``!`K___:`4`
M`*"V__\8!@``P+C__TP&``"0N?__L`8``."Y___(!@``@+O__Q0'``#>O?__
M6`<````````4``````````%Z4@`!>!`!&PP'")`!```4````'````-Z#__\H
M`````$8'$``````D````-````"A^__]P`P````X01@X82@\+=PB``#\:.RHS
M)"(`````%````%P```!P@?__"```````````````3````'0```!XA/__:A8`
M``!"#A"/`DD.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`T(6"@XX00XP
M00XH0@X@0@X80@X00@X(00L```!(````Q````)B:___,`````$(.$(\"0@X8
MC@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)L"@XX1`XP00XH0@X@0@X80@X0
M0@X(20L`(````!`!```<F___@P````!!#A"#`DH.L`$"<0H.$$$."$$+0```
M`#0!``"(F___9`$```!"#A".`D(.&(T#0@X@C`1!#BB&!4$.,(,&1P[0`7X*
M#C!!#BA!#B!"#AA"#A!"#@A+"P`8````>`$``+2<__]+`````$$.$(,";0X(
M````/````)0!``#HG/__V`````!"#A"-`D(.&(P#00X@A@1!#BB#!4<.J"!)
M#L`@`G8*#BA!#B!!#AA"#A!"#@A&"T@```#4`0``B)W__UD"````0@X0CP)"
M#AB.`T(.((T$0@XHC`5!#C"&!D0..(,'1PY@`QT!"@XX00XP00XH0@X@0@X8
M0@X00@X(10L0````(`(``)R?__\E`````````#@````T`@``N)___]<`````
M0@X0C`)!#AB&`T$.((,$1PZ@($P.H$!)#L!``JH*#B!$#AA!#A!"#@A!"Q``
M``!P`@``7*#__P4`````````8````(0"``!8H/__$@(```!"#A"/`D(.&(X#
M0@X@C01"#BB,!4$.,(8&00XX@P='#K@@3`[P(0)Q"@XX00XP00XH0@X@0@X8
M0@X00@X(2`L"N0[X(4\.@"):#O@A00[P(0```!@```#H`@``%*+__R(`````
M00X0@P)<#@@````X````!`,``"BB__\Q`0```$$.$(8"00X8@P-'#I@@20ZP
M(`+@"@X800X000X(1`M:"@X82`X000X(10M(````0`,``"RC__]<!````$(.
M$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9(#CB#!T0.4`,"!`H..$T.,$$.*$(.
M($(.&$(.$$(."$4+&````(P#``!`I___80````!$#B`"4`H."$0+`!@```"H
M`P``E*?__[0`````00X000X(1P[@`0`\````Q`,``#BH__\^`0```$(.$(P"
M00X8A@-!#B"#!$@,"Z"`!%$-!T0.L(`$`M`*#B!!#AA!#A!"#@A+"P``%```
M``0$```XJ?__'0````!$#A!8#@@`3````!P$``!`J?__UP````!"#A".`D(.
M&(T#0@X@C`1(#BB&!4<.,(,&1`Y``D(*#C!&#BA!#B!"#AA"#A!"#@A("V0.
M2$<.4&$.2$$.0`"L````;`0``-"I__]@!P```$(.$(\"20X8C@-.#B"-!$(.
M*(P%00XPA@9!#CB#!T<.@`,#.`(.B`-=#I`#7PZ(`T(.@`,">PH..$0.,$$.
M*$(.($(.&$(.$$(."$8+`TT!#H@#2PZ0`UH.B`-!#H`#6PZ(`T0.D`-.#I@#
M20Z@`TL.@`,#&@$*#CA$#C!!#BA"#B!"#AA"#A!"#@A-"P+?#H@#0PZ0`T8.
MB`-!#H`#`#`````<!0``@+#__R`"````0@X0C`)(#AB&`T$.((,$1`XP`W$!
M"@X@00X800X00@X(1`LT````4`4``&RR___.`````$$.$(8"00X8@P-.#C`"
M3PH.&$$.$$$."$<+`E<*#AA$#A!!#@A%"R@```"(!0``5'S__P0"````00X0
MA@)!#AB#`T0.4`-E`0H.&$,.$$$."$$+%````+0%``#8LO__10````!$#A`"
M0`X(2````,P%```0L___GP$```!"#A"/`D4.&(X#10X@C01"#BB,!40.,(8&
M10XX@P='#D`"Y@H..$$.,$$.*$(.($(.&$(.$$(."$(+`$`````8!@``9+3_
M_TT"````0@X0C@)&#AB-`T(.((P$00XHA@5$#C"#!@.9`0H.*$$.($(.&$(.
M$$(."$D+````````$````%P&``!^MO__$@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````H"8```````!@)@````````$`````````Z`(````````!`````````/,"
M````````'0````````!\!`````````P``````````"`````````-````````
M`+!>````````&0````````#`NP```````!L`````````"``````````:````
M`````,B[````````'``````````(``````````0`````````P`,```````#U
M_O]O`````%`&````````!0`````````0$`````````8`````````0`<`````
M```*`````````+$$````````"P`````````8`````````!4`````````````
M```````#`````````/"]`````````@`````````0!0```````!0`````````
M!P`````````7`````````(`7````````!P``````````%@````````@`````
M````@`$````````)`````````!@`````````'@`````````(`````````/O_
M_V\``````0``"`````#^__]O`````(`5````````____;P`````!````````
M`/#__V\`````PA0```````#Y__]O``````0`````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#0NP``````````````````````````
M```V(````````$8@````````5B````````!F(````````'8@````````AB``
M``````"6(````````*8@````````MB````````#&(````````-8@````````
MYB````````#V(`````````8A````````%B$````````F(0```````#8A````
M````1B$```````!6(0```````&8A````````=B$```````"&(0```````)8A
M````````IB$```````"V(0```````,8A````````UB$```````#F(0``````
M`/8A````````!B(````````6(@```````"8B````````-B(```````!&(@``
M`````%8B````````9B(```````!V(@```````(8B````````EB(```````"F
M(@```````+8B````````QB(```````#6(@```````.8B````````]B(`````
M```&(P```````!8C````````)B,````````V(P```````$8C````````5B,`
M``````!F(P```````'8C````````AB,`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````"E!!4BYP;0H``````````/AB
M````````1T-#.B`H4U5312!,:6YU>"D@,3,N,BXQ(#(P,C0P-3`Y(%MR979I
M<VEO;B!B-V$R-CDW-S,S9#$Y83`Y,V-B9&0P93(P,&9F8V4P-CEA-&)C.#$R
M70``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+G!R;W!E<G1Y`"YN;W1E
M+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM
M`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y
M;@`N<F5L82YP;'0`+FEN:70`+G!L="YG;W0`+G1E>'0`+F9I;FD`+G)O9&%T
M80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A
M<G)A>0`N9'EN86UI8P`N9&%T80`N8G-S`"YC;VUM96YT````````````````
M````````````````````````````````````````````````````````````
M````````````"P````$````"`````````!@#````````&`,````````<````
M`````````````````0```````````````````!,````'`````@`````````X
M`P```````#@#````````0`````````````````````@`````````````````
M```F````!P````(`````````>`,```````!X`P```````"0`````````````
M```````$````````````````````.0````<````"`````````)P#````````
MG`,````````@````````````````````!````````````````````$L````%
M`````@````````#``P```````,`#````````C`(````````'``````````@`
M````````!`````````!'````]O__;P(`````````4`8```````!0!@``````
M`/``````````!P`````````(````````````````````40````L````"````
M`````$`'````````0`<```````#0"`````````@````!````"``````````8
M`````````%D````#`````@`````````0$````````!`0````````L00`````
M``````````````$```````````````````!A````____;P(`````````PA0`
M``````#"%````````+P`````````!P`````````"``````````(`````````
M;@```/[__V\"`````````(`5````````@!4```````"```````````@````!
M````"````````````````````'T````$`````@``````````%@`````````6
M````````@`$````````'``````````@`````````&`````````"'````!```
M`$(`````````@!<```````"`%P```````!`%````````!P```!@````(````
M`````!@`````````D0````$````&```````````@`````````"`````````;
M````````````````````!````````````````````(P````!````!@``````
M```@(````````"`@````````<`,``````````````````!``````````$```
M``````"7`````0````8`````````D",```````"0(P````````@`````````
M```````````(``````````@`````````H`````$````&`````````*`C````
M````H",````````0.P``````````````````$````````````````````*8`
M```!````!@````````"P7@```````+!>````````#0``````````````````
M``0```````````````````"L`````0````(``````````&``````````8```
M`````,!````````````````````0````````````````````M`````$````"
M`````````,"@````````P*````````#\````````````````````!```````
M`````````````,(````!`````@````````#`H0```````,"A````````<`8`
M``````````````````@```````````````````#,````#@````,`````````
MP+L```````#`JP````````@````````````````````(``````````@`````
M````V`````\````#`````````,B[````````R*L````````(````````````
M````````"``````````(`````````.0````&`````P````````#0NP``````
M`-"K````````(`(````````(``````````@`````````$`````````";````
M`0````,`````````\+T```````#PK0```````!`"```````````````````(
M``````````@`````````[0````$````#``````````#``````````+``````
M```H````````````````````"````````````````````/,````(`````P``
M``````!`P````````"BP````````6````````````````````"``````````
M``````````#X`````0```#`````````````````````HL````````%8`````
M```````````````!``````````$``````````0````,`````````````````
M````````?K`````````!`0```````````````````0``````````````````
!````
